summaryrefslogtreecommitdiff
path: root/nuttx/configs/olimex-stm32-p207
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2014-01-24 13:50:23 -0600
committerGregory Nutt <gnutt@nuttx.org>2014-01-24 13:50:23 -0600
commitea439de0bb25f37ffc4004b6532bf53810511c3d (patch)
tree577b3e0aaa6a2878a6cc5d91792383781879fc28 /nuttx/configs/olimex-stm32-p207
parent1e646824d1fee99cba2f721cfc2181cfdd31d7f1 (diff)
downloadnuttx-ea439de0bb25f37ffc4004b6532bf53810511c3d.tar.gz
nuttx-ea439de0bb25f37ffc4004b6532bf53810511c3d.tar.bz2
nuttx-ea439de0bb25f37ffc4004b6532bf53810511c3d.zip
Rename up_buttoninit to board_button_intialize
Diffstat (limited to 'nuttx/configs/olimex-stm32-p207')
-rw-r--r--nuttx/configs/olimex-stm32-p207/src/up_boot.c2
-rw-r--r--nuttx/configs/olimex-stm32-p207/src/up_buttons.c13
2 files changed, 9 insertions, 6 deletions
diff --git a/nuttx/configs/olimex-stm32-p207/src/up_boot.c b/nuttx/configs/olimex-stm32-p207/src/up_boot.c
index 6f37eb090..29658ae54 100644
--- a/nuttx/configs/olimex-stm32-p207/src/up_boot.c
+++ b/nuttx/configs/olimex-stm32-p207/src/up_boot.c
@@ -90,7 +90,7 @@ void stm32_boardinitialize(void)
/* Configure on-board BUTTONs if BUTTON support has been selected. */
#ifdef CONFIG_ARCH_BUTTONS
- up_buttoninit();
+ board_button_initialize();
#endif
}
diff --git a/nuttx/configs/olimex-stm32-p207/src/up_buttons.c b/nuttx/configs/olimex-stm32-p207/src/up_buttons.c
index 87e24f364..789d5da28 100644
--- a/nuttx/configs/olimex-stm32-p207/src/up_buttons.c
+++ b/nuttx/configs/olimex-stm32-p207/src/up_buttons.c
@@ -40,7 +40,10 @@
#include <nuttx/config.h>
#include <stdint.h>
+
+#include <nuttx/arch.h>
#include <arch/board/board.h>
+
#include "olimex-stm32-p207.h"
#ifdef CONFIG_ARCH_BUTTONS
@@ -77,17 +80,17 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
****************************************************************************/
/****************************************************************************
- * Name: up_buttoninit
+ * Name: board_button_initialize
*
* Description:
* up_buttoninit() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
-void up_buttoninit(void)
+void board_button_initialize(void)
{
int i;
@@ -153,12 +156,12 @@ uint8_t up_buttons(void)
* Button support.
*
* Description:
* up_buttoninit() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After up_buttoninit() has been called, up_buttons() may be called to
* collect the state of all buttons. up_buttons() returns an 8-bit bit set
* with each bit associated with a button. See the BUTTON_*_BIT
* definitions in board.h for the meaning of each bit.
@@ -77,17 +80,17 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
*
* Description:
- * up_buttoninit() must be called to initialize button resources. After
+ * board_button_initialize() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
@@ -153,12 +156,12 @@ uint8_t up_buttons(void)
*
* Description:
- * up_buttoninit() must be called to initialize button resources. After
+ * board_button_initialize() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
@@ -153,12 +156,12 @@ uint8_t up_buttons(void)
* handlers.
*
- * After up_buttoninit() has been called, up_buttons() may be called to
+ * After board_button_initialize() has been called, up_buttons() may be called to
* collect the state of all buttons. up_buttons() returns an 8-bit bit set
* with each bit associated with a button. See the BUTTON_*_BIT